.. _wisconsin_breast_cancer_dataset:

Breast Cancer Wisconsin (Diagnostic)
=====================================

The `wisconsin breast cancer dataset` data frame has 569 rows and 31 columns. The first 30 variables
report the features are computed from a digitized image of a fine needle aspirate (FNA) of a breast mass.
They describe characteristics of the cell nuclei present in the image.
The last column indicates the class labels (Benign = 0 or Malignant = 1).

Source
------

Wolberg,William, Mangasarian,Olvi, Street,Nick, and Street,W.. (1995). 
Breast Cancer Wisconsin (Diagnostic). UCI Machine Learning Repository. https://doi.org/10.24432/C5DW2B.

References
----------

Street, W. N., Wolberg, W. H., & Mangasarian, O. L. (1993, July).
Nuclear feature extraction for breast tumor diagnosis.
In Biomedical image processing and biomedical visualization (Vol. 1905, pp. 861-870). SPIE.

